Learn R Programming

PVplr (version 0.1.2)

anomalies: Fixes the anomlies

Description

This function gets the data and finds the anomlies in weekends and weekdays and gives a dataframe with anomalies and anomaly columns

Usage

anomalies(df)

Value

df with two columns of cleaned_energy and anom_flag

Arguments

df

structured dataframe

Author

Arash Khalilnejad