Learn R Programming

PVplr (version 0.1.2)

anomaly_detector: detects rhw anomalies and returns a dataframw with cleaned and anom_flag column

Description

detects rhw anomalies and returns a dataframw with cleaned and anom_flag column

Usage

anomaly_detector(df, batch_days = 90)

Value

data with anomalies

Arguments

df

the strucutred data

batch_days

the batch of data that the anomaly detection is applied. Since time series decomposition is used, one seasonality will be applied for whole data which is inefficeint, if NA, will pass whole

Author

Arash Khalilnejad