returns quality information of time series data of PV
grade_pv(
df,
col = "poay",
id = "pv_id",
timestamp_col = "tmst",
timestamp_format = "%Y-%m-%d %H:%M:%S",
batch_days = 90
)the PV time series data. It can be the direct output of read.csv(file_name, stringsAsFactors = F)
column of the grading, default 'poay'
The name of the pv data
the character name of the timestamp column
the POSIXct format of the timestamp if conversion is needed
the batch of data that the anomaly detection is applied. Since time series decomposition is used, one seasonality will be applied for whole data which is inefficeint, if NA, will pass whole
Arash Khalilnejad