This function groups data by the specified time interval and performs a linear regression using the formula: power_var ~ irrad_var/istc * (nameplate_power + a*log(irrad_var/istc) + b*log(irrad_var/istc)^2 + c*(temp_var - tref) + d*(temp_var - tref)*log(irrad_var/istc) + e*(temp_var - tref)*log(irrad_var/istc)^2 + f*(temp_var - tref)^2). Predicted values of irradiance, temperature, and wind speed (if applicable) are added for reference. These values are the lowest daily high irradiance reading (over 300W/m^2), the average temperature over all data, and the average wind speed over all data.
plr_6k_model(
df,
var_list,
nameplate_power,
by = "month",
data_cutoff = 30,
predict_data = NULL
)Returns dataframe of results per passed time scale from 6K modeling
A dataframe containing pv data.
A list of the dataframe's standard variable names, obtained from
the output of plr_variable_check.
The rated power capability of the system, in watts.
String, either "day", "week", or "month". The time periods over which to group data for regression.
The number of data points needed to keep a value in the final table. Regressions over less than this number and their data will be discarded.
optional; Dataframe; If you have preferred estimations of irradiance, temperature, and wind speed, include them here to skip automatic generation. Format: Irradiance, Temperature, Wind (optional).