Learn R Programming

PVplr (version 0.1.2)

plr_pvheatmap: Title Heatmap generation for PV data

Description

Title Heatmap generation for PV data

Usage

plr_pvheatmap(
  df,
  col,
  timestamp_col,
  timestamp_format = "%Y-%m-%d %H:%M:%S",
  upper_threshold = 1,
  lower_threshold = 0,
  font_size = 12
)

Value

returns a ggplot object heatmap of the specified column

Arguments

df

dataframe containing at least the timestamp column and the variable to be plotted with the heatmap

col

the character name of the column to be ploted

timestamp_col

the character name of the timestamp column

timestamp_format

the POSIXct format of the timestamp if conversion is needed

upper_threshold

the fraction of upper data to include, 1 removes no data, 0.9 remove the top 1 percent etc.

lower_threshold

the fraction of lower data to remove, 0 removes no data, 0.01 remove the bottom 1 percent etc.

font_size

font size of the output plot

Examples

Run this code
# build heatmap
heat <- plr_pvheatmap(test_df, col = "g_poa", timestamp_col = "timestamp", 
                      upper_threshold = 0.99, lower_threshold = 0)
# display heatmap
plot(heat)

Run the code above in your browser using DataLab