detects rhw anomalies and returns a dataframw with cleaned and anom_flag column
anomaly_detector(df, batch_days = 90)data with anomalies
the strucutred data
the batch of data that the anomaly detection is applied. Since time series decomposition is used, one seasonality will be applied for whole data which is inefficeint, if NA, will pass whole
Arash Khalilnejad