Converts appropriate columns to numeric without specifying
the name of the column. All columns from hbase are read as factors.
Columns are tested to see if they should be numeric by forcing conversion
to numeric. Columns that subsequently contain NA's are not numeric; if not,
they are set to numeric.
Usage
plr_convert_columns(df)
Value
Returns original dataframe with columns corrected to proper classes